@@ -16,13 +16,13 @@ def clear_mem():
     """
     from .. import dir_char, system, external_exec
 
-    if dir_char == '\\':
+    if dir_char == "\\":
         print("Not support")
     else:
         if system.startswith("darwin"):
             external_exec("sudo purge")
         else:
-            external_exec('sync')
+            external_exec("sync")
             external_exec("echo 3 > /proc/sys/vm/drop_caches")
 
 
@@ -33,4 +33,5 @@ def get_core_num():
     :return: core num
     """
     from .. import requirePackage
-    return requirePackage('psutil').cpu_count()
+
+    return requirePackage("psutil").cpu_count()
