@@ -236,18 +236,17 @@ def translate(content: str = None):
     """
     from . import trans_engine
 
-    pyperclip = requirePackage("pyperclip")
-    if trans_engine != "default":
-        from .API.TencentCloud import translate
-    else:
-        from .API.alapi import translate
+    if trans_engine == "default":
+        trans_engine = "alapi"
+
+    _translate = requirePackage(f".API.{trans_engine}", "translate")
 
     output_flag = False if content else True
     if not content:
         content = " ".join(sys.argv[2:])
     if not content:
         try:
-            content = pyperclip.paste()
+            content = requirePackage("pyperclip", "paste")()
         except:
             from . import qs_default_input
 
@@ -257,7 +256,7 @@ def translate(content: str = None):
                 else "抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:"
             )
     if content:
-        ret = translate(content.replace("\n", " "))
+        ret = _translate(content.replace("\n", " "))
         if output_flag:
             qs_default_console.print(ret) if ret else qs_default_console.log(
                 qs_error_string, "Translate Failed!"
@@ -386,7 +385,6 @@ def AipNLP():
     from .API.BaiduCloud import AipNLP
 
     pyperclip = requirePackage("pyperclip")
-    import pyperclip
 
     pyperclip.paste()
     ct = sys.argv[2:]
@@ -816,6 +814,7 @@ def loli():
                 not save_flag,
                 set_proxy=proxy,
                 set_referer="https://i.pximg.net",
+                qs_console_status=qs_default_console.status("展示图片中.."),
             )
 
         qs_default_console.print(
@@ -1231,9 +1230,11 @@ def gpt():
     :return:
     """
     from .API.ChatGPT import chatGPT
-    from . import _ask, table_cell
+    from . import _ask
 
-    qs_default_console.print(qs_info_string, "Type 'exit' to exit" if user_lang != "zh" else "输入 'exit' 退出")
+    qs_default_console.print(
+        qs_info_string, "Type 'exit' to exit" if user_lang != "zh" else "输入 'exit' 退出"
+    )
 
     while (
         prompt := _ask(
@@ -1247,9 +1248,6 @@ def gpt():
             "Thinking..." if user_lang != "zh" else "思考中..."
         ):
             res = chatGPT(prompt)
-        res = "\n".join(
-            [table_cell(i, qs_default_console.width) for i in res.split("\n")]
-        )
         qs_default_console.print(
             "[bold green]" + ("Answer" if user_lang != "zh" else "回答") + "[/]\n",
             justify="center",
